@@ -31,7 +31,7 @@ class Storage(driver.Base):
         
     def _init_path(self, path=None):
         if path:
-            return path.replace("/", "_")
+            return path.replace("/", ".")
         return path
 
     def content_redirect_url(self, path):
@@ -119,7 +119,7 @@ class Storage(driver.Base):
             
             for file in files:
                 logger.info("list_directory key:%s" % file["Key"])
-                yield file["Key"]
+                yield file["Key"].replace(".", "/")
         except Exception as e:
             logger.error("list_directory error:%s" % e)
             raise exceptions.FileNotFoundError("File not found %s" % path)
